Constraint class

The base class of all type of the constraints.

Inheritance
Implementers

Constructors

Constraint()

Properties

addedToIsland ↔ bool
Internal
getter/setter pair
body1 ↔ RigidBody?
first body of the constraint.
getter/setter pair
body2 ↔ RigidBody?
second body of the constraint.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
parent ↔ World?
parent world of the constraint.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

awake() → void
wake the body
inherited
dispose() → void
Dispose of the body
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postSolve() → void
Do the post-processing.
preSolve(double timeStep, double invTimeStep) → void
Prepare for solving the constraint
remove() → void
Remove the body
inherited
setParent(World world) → void
Set the parent of the body
inherited
sleep() → void
Run the sleep function
inherited
solve() → void
Solve the constraint. This is usually called iteratively.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited